Times class

Constructors

Times(int download1, int download2, int download3, int upload1, int upload2, int upload3)
Times.fromXMLElement(XmlElement? element)

Properties

download1 ↔ int
getter/setter pair
download2 ↔ int
getter/setter pair
download3 ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upload1 ↔ int
getter/setter pair
upload2 ↔ int
getter/setter pair
upload3 ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited